@@ -16,6 +16,7 @@ import json
 from datetime import timedelta
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
+from uuid import uuid4
 
 from assertionengine import AssertionOperator, verify_assertion
 from robot.utils import get_link_path  # type: ignore
@@ -349,6 +350,8 @@ class PlaywrightState(LibraryComponent):
             raise ValueError(
                 f"Must use {SupportedBrowsers.chromium.name} browser with channel definition"
             )
+        trace_dir = self.traces_output / str(uuid4())
+        params["tracesDir"] = str(trace_dir)
         options = json.dumps(params, default=str)
         logger.info(options)
 
@@ -389,6 +392,7 @@ class PlaywrightState(LibraryComponent):
         hideRfBrowser: bool = False,
         recordVideo: Optional[RecordVideo] = None,
         recordHar: Optional[RecordHar] = None,
+        tracing: Optional[str] = None,
     ) -> str:
         """Create a new BrowserContext with specified options.
         See `Browser, Context and Page` for more information about BrowserContext.
@@ -506,6 +510,13 @@ class PlaywrightState(LibraryComponent):
 
         The ${OUTPUTDIR}/browser/ is removed at the first suite startup.
 
+        ``tracing`` is file name where the [https://playwright.dev/docs/api/class-tracing/|tracing]
+         file is saved. Example trace.zip will be saved to ${OUTPUT_DIR}/traces.zip. Temporary trace
+         files will be saved to ${OUTPUT_DIR}/Browser/traces. If file name is defined, tracing will
+         be enabled for all pages in the context. Tracing is automatically closed when context is
+         closed. Temporary trace files will be automatically deleted at start of each test
+         execution.
+
         Example:
         | Test an iPhone
         |     ${device}=    `Get Device`    iPhone X
@@ -513,8 +524,8 @@ class PlaywrightState(LibraryComponent):
         |     `New Page`    http://example.com
 
         A BrowserContext is the Playwright object that controls a single browser profile.
-        Within a context caches and cookies are shared.
-        See [https://playwright.dev/docs/api/class-browser#browsernewcontextoptions|Playwright browser.newContext]
+        Within a context caches and cookies are shared. See
+        [https://playwright.dev/docs/api/class-browser#browsernewcontextoptions|Playwright browser.newContext]
         for a list of supported options.
 
         If there's no open Browser this keyword will open one. Does not create pages.
@@ -530,21 +541,16 @@ class PlaywrightState(LibraryComponent):
         params = convert_typed_dict(self.new_context.__annotations__, params)
         if not videosPath:
             params.pop("videoSize", None)
+        trace_file = params.pop("tracing", None)
         masked_params = self._mask_credentials(params.copy())
         options = json.dumps(params, default=str)
         logger.info(json.dumps(masked_params, default=str))
-        with self.playwright.grpc_channel() as stub:
-            response = stub.NewContext(
-                Request().Context(
-                    rawOptions=options,
-                    hideRfBrowser=hideRfBrowser,
-                    defaultTimeout=int(self.timeout),
-                )
-            )
-        log_msg, json_data = response.log.split("options:")
-        log_msg = f"{log_msg} options:"
-        json_data = self._mask_credentials(json.loads(json_data))
-        logger.info(f"{log_msg}\n{json.dumps(json_data)}")
+        trace_file = Path(self.outputdir, trace_file) if tracing else ""
+        response = self._new_context(options, hideRfBrowser, trace_file)
+        print(response.contextOptions)
+        context_options = self._mask_credentials(json.loads(response.contextOptions))
+        logger.info(response.log)
+        logger.info(context_options)
         if response.newBrowser:
             logger.info(
                 "No browser was open. New browser was automatically opened "
@@ -553,6 +559,19 @@ class PlaywrightState(LibraryComponent):
         self.context_cache.add(response.id, self._get_video_size(params))
         return response.id
 
+    # Only to ease unit test mocking.
+    def _new_context(self, options: str, hide_rf_browser: bool, trace_file: str):
+        with self.playwright.grpc_channel() as stub:
+            response = stub.NewContext(
+                Request().Context(
+                    rawOptions=options,
+                    hideRfBrowser=hide_rf_browser,
+                    defaultTimeout=int(self.timeout),
+                    traceFile=str(trace_file),
+                )
+            )
+            return response
+
     def _mask_credentials(self, data: dict):
         if "httpCredentials" in data:
             data["httpCredentials"] = "XXX"
